Documentation
¶
Index ¶
- type LevelLog
- func (l *LevelLog) Errorf(format string, v ...interface{})
- func (l *LevelLog) Errorln(v ...interface{})
- func (l *LevelLog) Fatalf(format string, v ...interface{})
- func (l *LevelLog) Fatalln(v ...interface{})
- func (l *LevelLog) Infof(format string, v ...interface{})
- func (l *LevelLog) Infoln(v ...interface{})
- func (l *LevelLog) SetVerbosity(verbose bool, quiet bool)
- func (l *LevelLog) Verbosef(format string, v ...interface{})
- func (l *LevelLog) Verboseln(v ...interface{})
- func (l *LevelLog) Warnf(format string, v ...interface{})
- func (l *LevelLog) Warnln(v ...interface{})
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LevelLog ¶
LevelLog custom type to allow a verbose mode and handling of levels with a prefix
func NewLevelLog ¶
func NewLevelLog() *LevelLog
NewLevelLog setups a logger with the proper configuration for the underlying log
func (*LevelLog) Errorln ¶
func (l *LevelLog) Errorln(v ...interface{})
Errorln prints a message with ERROR: prefix using log.Println
func (*LevelLog) Fatalln ¶
func (l *LevelLog) Fatalln(v ...interface{})
Fatalln prints a message with FATAL: prefix using log.Println
func (*LevelLog) Infoln ¶
func (l *LevelLog) Infoln(v ...interface{})
Infoln prints a message with INFO: prefix using log.Println
func (*LevelLog) SetVerbosity ¶
SetVerbose toggles verbose mode
func (*LevelLog) Verbosef ¶
Verbosef prints with log.Printf a message with DEBUG: prefix using log.Printf, only when verbose mode is true
func (*LevelLog) Verboseln ¶
func (l *LevelLog) Verboseln(v ...interface{})
Verboseln prints a message with DEBUG: prefix using log.Println, only when verbose mode is true
Click to show internal directories.
Click to hide internal directories.